@@ -31,7 +31,7 @@ def __determine_default_gpg_home() -> Path:
 
 def __default_gpg_home() -> GPG:
     """
-    __defaultGpgHome tries to load the variable 'GNUPGHOME' or to guess it
+    __default_gpg_home tries to load the variable 'GNUPGHOME' or to guess it
     """
     manual = os.getenv("GNUPGHOME")
 
@@ -120,7 +120,7 @@ def gpg_sha256sums(
 
 
 def create_verify(
-    sha256sums: Callable[[], Dict[str, str]]
+    sha256sums: Callable[[], Dict[str, str]],
 ) -> Callable[[Path], bool]:
     """
     create_verify is returning a closure based on the sha256sums.
